==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let FilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (FilterExpressionDescriptionMetadata.a == null) {
                FilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterExpressionDescriptionMetadata.c(FilterExpressionDescriptionMetadata.a);
            }
            if (a.k(FilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(FilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FilterExpressionDescriptionMetadata.b(a);
            a.ac("FilterExpression", FilterExpressionDescriptionMetadata.a);
        }
    }
    FilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterExpressionDescriptionMetadata, 'FilterExpressionDescriptionMetadata');
    FilterExpressionDescriptionMetadata.a = null;
    return FilterExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/FilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let FilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (FilterExpressionDescriptionMetadata.a == null) {
                FilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterExpressionDescriptionMetadata.c(FilterExpressionDescriptionMetadata.a);
            }
            if (a.k(FilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(FilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
        }
        static d(a) {
            FilterExpressionDescriptionMetadata.b(a);
            a.ad("FilterExpression", FilterExpressionDescriptionMetadata.a);
        }
    }
    FilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterExpressionDescriptionMetadata, 'FilterExpressionDescriptionMetadata');
    FilterExpressionDescriptionMetadata.a = null;
    return FilterExpressionDescriptionMetadata;
})();
